pub struct NodeIdPositionBucket { /* private fields */ }Expand description
A memory effecient node location store nodes with the same id are often very close together. This will bucket nodes based on id, and store several relative offsets (in a compressed form)